Online GUI
==========

We have also built an online graphical user interface (GUI) for those interested. 
The GUI has the same query functions as this python client and allows the user to download lightcurves in CSV.
Because of technical limitations this GUI limits catalog query results to 10,000 rows while the python client is limited to 1,000,000 rows.
However, light curves are still available in full.

.. image :: /_static/site.png


